package com.perisic.beds.Control;

import java.rmi.Naming;
import java.rmi.RemoteException;
import java.rmi.NotBoundException;
import com.perisic.beds.rmi.Recyterface;

import java.net.MalformedURLException;
import java.util.Vector;

/**
 * This class handles the connection to a remote recycling machine.
 * @author AH, AM, SA
 */
public class MachineConnection
{
    public boolean empty = true;

    private String ip;
    private String cookie;
    private Recyterface server;

    /**
     * @param ipNo The IP of the remote machine
     */
    public MachineConnection(String ipNo)
    {
        empty = false;

        ip = ipNo;
    }

    /**
     * Attempts to locate and login to a recycling machine at the previously given IP
     * @param password The password of the remote machine
     * @return A status int -4 and 1. 1=success, -1=Remote related exception or no IP, -2=bad password, -3=machine already logged into, -4=other failure
     */
    public int tryConnect(String password)
    {
        if (ip == null || ip.equals(""))
        {
            return -1;
        }
        try
        {
            server = (Recyterface)Naming.lookup("rmi://" + ip + "/RecyService");
            String result = server.login(password);
            System.out.println(result);
            if (result.equals("bad password"))
            {
                return -2;
            }
            else if (result.equals("already logged"))
            {
                return -3;
            }
            else
            {
                cookie = result;
                return 1;
            }
        }
        catch (MalformedURLException ex)
        {
            return -1;
        }
        catch (NotBoundException ex)
        {
            return -1;
        }
        catch (RemoteException ex)
        {
            return -1;
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
            return -4;
        }
    }

    /**
     * @return The item total of the remote machine
     */
    public int getTotal()
    {
        int result = 0;
        try
        {
            result = server.getItemCount(cookie);
        }
        catch (Exception ex)
        {
            return -2;
        }
        return result;
    }

    /**
     * Logs out of the remote machine
     */
    public void disconnect()
    {
        try
        {
            server.logout();
        }
        catch(Exception ex)
        {
            ex.printStackTrace();
        }
        finally
        {
            ip = null;
            server = null;
            cookie = null;
        }
    }

    /**
     * Empties the remote machine
     */
    public void emptyMachine()
    {
        try
        {
            server.emptyMachine(cookie);
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
    }

    /**
     * Retrieves feedback from the remote machine
     * @return Feedback from the remote machine
     */
    public Vector<String> getFeedback()
    {
        Vector<String> result;

        try
        {
            result = server.getFeedback(cookie);
        }
        catch (Exception ex)
        {
            result = new Vector<String>();
            result.add("Error encountered: " + ex.toString());
        }
        return result;
    }

    /**
     * Retries the detailed item total from the remote machine
     * @return A formatted string of the detailed item total from the remote machine
     */
    public String getDetails()
    {
        Vector<String> result;
        String[] resultS;

        try
        {
            result = server.getDetailedTotal(cookie);
            resultS = result.toArray(new String[result.size()]);
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
            return "Error getting details";
        }

        if(resultS.length > 1)
        {
            String ret = "";
            ret += resultS[0] + " Cans\r\n";
            ret += resultS[1] + " Plastic Bottles\r\n";
            ret += resultS[2] + " Glass Bottles\r\n";
            ret += resultS[3] + " Bags\r\n";
            ret += resultS[4] + " Crates\r\n";
            return ret;
        }
        else
        {
            return "Error getting details";
        }
    }
}
