package com.perisic.beds.Control;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Vector;

/**
 * The main GUI class of the controller
 * @author AH, AM, SA
 */
public class ControlForm implements ActionListener
{
    private JPanel outside;
    private JPanel topPanel;
    private JPanel tlPanel;
    private JLabel labList;
    private JComboBox boxConnectTo;
    private JButton butConnect;
    private JButton butRefresh;
    private JLabel labNameA;
    private JLabel labCountA;
    private JButton detailsButtonA;
    private JButton optionsButtonA;
    private JButton disconnectButtonA;
    private JButton optionsButtonB;
    private JButton disconnectButtonB;
    private JLabel labCountB;
    private JLabel labNameB;
    private JPanel trPanel;
    private JButton detailsButtonB;
    private JButton optionsButtonC;
    private JButton disconnectButtonC;
    private JLabel labCountC;
    private JLabel labNameC;
    private JPanel blPanel;
    private JButton detailsButtonC;
    private JButton optionsButtonD;
    private JButton disconnectButtonD;
    private JLabel labCountD;
    private JLabel labNameD;
    private JPanel brPanel;
    private JButton detailsButtonD;

    private int conCount;
    private MachineConnection[] mc;
    private PingThread[] pt;

    public ControlForm()
    {
        conCount = 0;
        mc = new MachineConnection[4];
        pt = new PingThread[4];

        ActionListener listener = this;

        butConnect.addActionListener(listener);
        butRefresh.addActionListener(listener);
        detailsButtonA.addActionListener(listener);
        optionsButtonA.addActionListener(listener);
        disconnectButtonA.addActionListener(listener);
        detailsButtonB.addActionListener(listener);
        optionsButtonB.addActionListener(listener);
        disconnectButtonB.addActionListener(listener);
        detailsButtonC.addActionListener(listener);
        optionsButtonC.addActionListener(listener);
        disconnectButtonC.addActionListener(listener);
        detailsButtonD.addActionListener(listener);
        optionsButtonD.addActionListener(listener);
        disconnectButtonD.addActionListener(listener);

        updateIPList();
    }

    /**
     * Starts the GUI
     *
     * @param args arguments
     */
    public static void main(String[] args)
    {
        JFrame frame = new JFrame("Recycling Machine Remote Control");
        frame.setContentPane(new ControlForm().outside);
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.pack();
        frame.setSize(650, 450);
        frame.setVisible(true);
    }


    /**
     * Retrieves the list of machine IPs
     */
    private void updateIPList()
    {
        Vector<String> v = HTTPHandler.getData(
                "http://spacewalrus.net/cgi-bin/get-ip-compara.py", null);

        if (!v.isEmpty())
        {
            boxConnectTo.addItem("");
            for (String s : v)
            {
                boxConnectTo.addItem(s);
            }
        }
    }

    /**
     * Returns the first unused MachineConnection slot
     *
     * @return The first unused MachineConnection slot
     */
    private int findFreeConnection()
    {
        for (int i = 0; i < mc.length; i++)
        {
            if (mc[i] == null || mc[i].empty)
            {
                return i;
            }
        }
        return 4;
    }

    /**
     * Returns a count label associated with the MachineConnection corresponding integer
     *
     * @param i An int between 0 and 3
     * @return The count label associated with the MachineConnection corresponding integer
     */
    private JLabel getCountLab(int i)
    {
        switch (i)
        {
            case 0:
                return labCountA;
            case 1:
                return labCountB;
            case 2:
                return labCountC;
            case 3:
                return labCountD;
            default:
                return null;
        }
    }

    /**
     * Returns a name label associated with the MachineConnection corresponding integer
     *
     * @param i An int between 0 and 3
     * @return The name label associated with the MachineConnection corresponding integer
     */
    private JLabel getNameLab(int i)
    {
        switch (i)
        {
            case 0:
                return labNameA;
            case 1:
                return labNameB;
            case 2:
                return labNameC;
            case 3:
                return labNameD;
            default:
                return null;
        }
    }

    /**
     * Returns an int indicating which number machine a given button is associated with
     *
     * @param butt A JButton from the GUI
     * @return Int indicating which number machine a given button is associated with
     */
    public int butToInt(JButton butt)
    {
        if (butt.equals(disconnectButtonA) || butt.equals(detailsButtonA)
                || butt.equals(optionsButtonA))
        {
            return 0;
        }
        else if (butt.equals(disconnectButtonB) || butt.equals(detailsButtonB)
                || butt.equals(optionsButtonB))
        {
            return 1;
        }
        if (butt.equals(disconnectButtonC) || butt.equals(detailsButtonC)
                || butt.equals(optionsButtonC))
        {
            return 2;
        }
        if (butt.equals(disconnectButtonD) || butt.equals(detailsButtonD)
                || butt.equals(optionsButtonD))
        {
            return 3;
        }
        else
        {
            return -1;
        }
    }

    /**
     * Handler for the Details buttons. Runs the MachineConnection's getDetails() method.
     *
     * @param conNo Number of the MachineConnection slot
     */
    private void getDetails(int conNo)
    {
        try
        {
            if (mc[conNo] != null && !mc[conNo].empty)
            {
                String details = mc[conNo].getDetails();
                String detailsF = "Connection #" + (conNo + 1) + " contains:\r\n";
                MessageThread mt = new MessageThread(detailsF + details);
                mt.start();
            }
        } catch (NullPointerException ex)
        {
            ex.printStackTrace();
        }
    }

    /**
     * Handler for the Options buttons. Starts an option thread.
     *
     * @param conNo Number of the MachineConnection slot
     */
    private void showOptions(int conNo)
    {
        try
        {
            if (mc[conNo] != null && !mc[conNo].empty)
            {
                OptionThread ot = new OptionThread(mc[conNo]);
                ot.start();
            }
        } catch (NullPointerException ex)
        {
            ex.printStackTrace();
        }
    }

    /**
     * Handler for the Diconnect buttons. Closes a machine connection.
     *
     * @param conNo Number of the MachineConnection slot
     */
    private void disconnect(int conNo)
    {
        try
        {
            if (mc[conNo] != null && !mc[conNo].empty)
            {
                pt[conNo].interrupt();
                conCount--;
                mc[conNo].disconnect();
                mc[conNo].empty = true;
                getNameLab(conNo).setText("NAME");
                getCountLab(conNo).setText("COUNT /100");
            }
        } catch (NullPointerException ex)
        {
            ex.printStackTrace();
        }
    }

    /**
     * Attempts to start a new MachineConnection
     */
    private void connect()
    {
        int conNo = findFreeConnection();
        String ip = boxConnectTo.getSelectedItem().toString();

        mc[conNo] = new MachineConnection(ip);

        JPasswordField pwd = new JPasswordField();
        int action = JOptionPane.showConfirmDialog(null, pwd, "Enter Password",
                                                   JOptionPane.OK_CANCEL_OPTION);

        if (action >= 0)
        {
            switch (mc[conNo].tryConnect(new String(pwd.getPassword())))
            {
                case 1:
                    conCount++;
                    break;
                case -1:
                    JOptionPane.showMessageDialog(null, "No machine found at " + ip);
                    mc[conNo].empty = true;
                    return;
                case -2:
                    JOptionPane.showMessageDialog(null, "Incorrect password");
                    mc[conNo].empty = true;
                    return;
                case -3:
                    JOptionPane.showMessageDialog(null,
                                                  "A user is already"
                                                          + " logged into that machine");
                    mc[conNo].empty = true;
                    return;
                case -4:
                    JOptionPane.showMessageDialog(null,
                                                  "Unknown error encountered,"
                                                          + " please consult your"
                                                          + " system administrator");
                    mc[conNo].empty = true;
                    return;
            }
            getNameLab(conNo).setText(ip);
            getCountLab(conNo).setText(mc[conNo].getTotal() + " /100");
            pt[conNo] = new PingThread(mc[conNo], getCountLab(conNo));
            pt[conNo].start();
        }
    }

    public void actionPerformed(ActionEvent e)
    {
        String type = e.getActionCommand();
        if (type.equals("Details"))
        {
            getDetails(butToInt((JButton) e.getSource()));
        }
        else if (type.equals("Options"))
        {
            showOptions(butToInt((JButton) e.getSource()));
        }
        else if (type.equals("Disconnect"))
        {
            int i = butToInt((JButton) e.getSource());
            disconnect(i);
            getCountLab(i).setForeground(new Color(0, 0, 0));
        }
        else if (type.equals("Connect"))
        {
            if (conCount < 4)
            {
                connect();
            }
            else
            {
                JOptionPane.showMessageDialog(null,
                                              "Only four connections permitted at once");
            }
        }
        else if (type.equals("Refresh List"))
        {
            boxConnectTo.removeAllItems();
            updateIPList();
        }
    }

    {
// GUI initializer generated by IntelliJ IDEA GUI Designer
// >>> IMPORTANT!! <<<
// DO NOT EDIT OR ADD ANY CODE HERE!
        $$$setupUI$$$();
    }

    /**
     * Method generated by IntelliJ IDEA GUI Designer
     * >>> IMPORTANT!! <<<
     * DO NOT edit this method OR call it in your code!
     *
     * @noinspection ALL
     */
    private void $$$setupUI$$$()
    {
        outside = new JPanel();
        outside.setLayout(new com.intellij.uiDesigner.core.GridLayoutManager(6, 5, new Insets(0, 0, 0, 0), -1, -1));
        topPanel = new JPanel();
        topPanel.setLayout(new com.intellij.uiDesigner.core.GridLayoutManager(1, 4, new Insets(0, 0, 0, 0), -1, -1));
        outside.add(topPanel, new com.intellij.uiDesigner.core.GridConstraints(0, 0, 1, 5,
                                                                               com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                               com.intellij.uiDesigner.core.GridConstraints.FILL_BOTH,
                                                                               com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                               com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                               null, null, null, 0, false));
        labList = new JLabel();
        labList.setText("Connect To: ");
        topPanel.add(labList, new com.intellij.uiDesigner.core.GridConstraints(0, 0, 1, 1,
                                                                               com.intellij.uiDesigner.core.GridConstraints.ANCHOR_WEST,
                                                                               com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                               com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                               com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                               null, null, null, 0, false));
        boxConnectTo = new JComboBox();
        boxConnectTo.setEditable(true);
        topPanel.add(boxConnectTo, new com.intellij.uiDesigner.core.GridConstraints(0, 1, 1, 1,
                                                                                    com.intellij.uiDesigner.core.GridConstraints.ANCHOR_WEST,
                                                                                    com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                                    com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                    com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                    null, null, null, 0, false));
        butConnect = new JButton();
        butConnect.setText("Connect");
        topPanel.add(butConnect, new com.intellij.uiDesigner.core.GridConstraints(0, 2, 1, 1,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                  null, null, null, 0, false));
        butRefresh = new JButton();
        butRefresh.setText("Refresh List");
        topPanel.add(butRefresh, new com.intellij.uiDesigner.core.GridConstraints(0, 3, 1, 1,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                  null, null, null, 0, false));
        final com.intellij.uiDesigner.core.Spacer spacer1 = new com.intellij.uiDesigner.core.Spacer();
        outside.add(spacer1, new com.intellij.uiDesigner.core.GridConstraints(1, 1, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_VERTICAL,
                                                                              1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              null, null, null, 0, false));
        tlPanel = new JPanel();
        tlPanel.setLayout(new com.intellij.uiDesigner.core.GridLayoutManager(3, 3, new Insets(0, 0, 0, 0), -1, -1));
        outside.add(tlPanel, new com.intellij.uiDesigner.core.GridConstraints(2, 1, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_BOTH,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              null, null, null, 0, true));
        tlPanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createLineBorder(new Color(-10066330)),
                                                           "Connection #1"));
        labNameA = new JLabel();
        labNameA.setText("NAME");
        tlPanel.add(labNameA, new com.intellij.uiDesigner.core.GridConstraints(0, 0, 1, 3,
                                                                               com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                               com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                               com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                               com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                               null, null, null, 0, false));
        labCountA = new JLabel();
        labCountA.setText("COUNT / 100");
        tlPanel.add(labCountA, new com.intellij.uiDesigner.core.GridConstraints(1, 0, 1, 3,
                                                                                com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                                com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                null, null, null, 0, false));
        detailsButtonA = new JButton();
        detailsButtonA.setText("Details");
        tlPanel.add(detailsButtonA, new com.intellij.uiDesigner.core.GridConstraints(2, 0, 1, 1,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.ANCHOR_SOUTHWEST,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                     null, null, null, 0, false));
        optionsButtonA = new JButton();
        optionsButtonA.setText("Options");
        tlPanel.add(optionsButtonA, new com.intellij.uiDesigner.core.GridConstraints(2, 1, 1, 1,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.ANCHOR_SOUTH,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                     null, null, null, 0, false));
        disconnectButtonA = new JButton();
        disconnectButtonA.setText("Disconnect");
        tlPanel.add(disconnectButtonA, new com.intellij.uiDesigner.core.GridConstraints(2, 2, 1, 1,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.ANCHOR_SOUTHEAST,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                        null, null, null, 0, false));
        final com.intellij.uiDesigner.core.Spacer spacer2 = new com.intellij.uiDesigner.core.Spacer();
        outside.add(spacer2, new com.intellij.uiDesigner.core.GridConstraints(2, 4, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              1, null, null, null, 0, false));
        final com.intellij.uiDesigner.core.Spacer spacer3 = new com.intellij.uiDesigner.core.Spacer();
        outside.add(spacer3, new com.intellij.uiDesigner.core.GridConstraints(2, 0, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              1, null, null, null, 0, false));
        final com.intellij.uiDesigner.core.Spacer spacer4 = new com.intellij.uiDesigner.core.Spacer();
        outside.add(spacer4, new com.intellij.uiDesigner.core.GridConstraints(3, 1, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_VERTICAL,
                                                                              1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              null, null, null, 0, false));
        final com.intellij.uiDesigner.core.Spacer spacer5 = new com.intellij.uiDesigner.core.Spacer();
        outside.add(spacer5, new com.intellij.uiDesigner.core.GridConstraints(3, 3, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_VERTICAL,
                                                                              1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              null, null, null, 0, false));
        final com.intellij.uiDesigner.core.Spacer spacer6 = new com.intellij.uiDesigner.core.Spacer();
        outside.add(spacer6, new com.intellij.uiDesigner.core.GridConstraints(1, 3, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_VERTICAL,
                                                                              1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              null, null, null, 0, false));
        final com.intellij.uiDesigner.core.Spacer spacer7 = new com.intellij.uiDesigner.core.Spacer();
        outside.add(spacer7, new com.intellij.uiDesigner.core.GridConstraints(5, 3, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_VERTICAL,
                                                                              1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              null, null, null, 0, false));
        final com.intellij.uiDesigner.core.Spacer spacer8 = new com.intellij.uiDesigner.core.Spacer();
        outside.add(spacer8, new com.intellij.uiDesigner.core.GridConstraints(5, 1, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_VERTICAL,
                                                                              1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              null, null, null, 0, false));
        trPanel = new JPanel();
        trPanel.setLayout(new com.intellij.uiDesigner.core.GridLayoutManager(3, 3, new Insets(0, 0, 0, 0), -1, -1));
        outside.add(trPanel, new com.intellij.uiDesigner.core.GridConstraints(2, 3, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_BOTH,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              null, null, null, 0, true));
        trPanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createLineBorder(new Color(-10066330)),
                                                           "Connection #2"));
        labNameB = new JLabel();
        labNameB.setText("NAME");
        trPanel.add(labNameB, new com.intellij.uiDesigner.core.GridConstraints(0, 0, 1, 3,
                                                                               com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                               com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                               com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                               com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                               null, null, null, 0, false));
        labCountB = new JLabel();
        labCountB.setText("COUNT / 100");
        trPanel.add(labCountB, new com.intellij.uiDesigner.core.GridConstraints(1, 0, 1, 3,
                                                                                com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                                com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                null, null, null, 0, false));
        detailsButtonB = new JButton();
        detailsButtonB.setText("Details");
        trPanel.add(detailsButtonB, new com.intellij.uiDesigner.core.GridConstraints(2, 0, 1, 1,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.ANCHOR_SOUTHWEST,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                     null, null, null, 0, false));
        optionsButtonB = new JButton();
        optionsButtonB.setText("Options");
        trPanel.add(optionsButtonB, new com.intellij.uiDesigner.core.GridConstraints(2, 1, 1, 1,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.ANCHOR_SOUTH,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                     null, null, null, 0, false));
        disconnectButtonB = new JButton();
        disconnectButtonB.setText("Disconnect");
        trPanel.add(disconnectButtonB, new com.intellij.uiDesigner.core.GridConstraints(2, 2, 1, 1,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.ANCHOR_SOUTHEAST,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                        null, null, null, 0, false));
        blPanel = new JPanel();
        blPanel.setLayout(new com.intellij.uiDesigner.core.GridLayoutManager(3, 3, new Insets(0, 0, 0, 0), -1, -1));
        outside.add(blPanel, new com.intellij.uiDesigner.core.GridConstraints(4, 1, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_BOTH,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              null, null, null, 0, true));
        blPanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createLineBorder(new Color(-10066330)),
                                                           "Connection #3"));
        labNameC = new JLabel();
        labNameC.setText("NAME");
        blPanel.add(labNameC, new com.intellij.uiDesigner.core.GridConstraints(0, 0, 1, 3,
                                                                               com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                               com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                               com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                               com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                               null, null, null, 0, false));
        labCountC = new JLabel();
        labCountC.setText("COUNT / 100");
        blPanel.add(labCountC, new com.intellij.uiDesigner.core.GridConstraints(1, 0, 1, 3,
                                                                                com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                                com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                null, null, null, 0, false));
        detailsButtonC = new JButton();
        detailsButtonC.setText("Details");
        blPanel.add(detailsButtonC, new com.intellij.uiDesigner.core.GridConstraints(2, 0, 1, 1,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.ANCHOR_SOUTHWEST,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                     null, null, null, 0, false));
        optionsButtonC = new JButton();
        optionsButtonC.setText("Options");
        blPanel.add(optionsButtonC, new com.intellij.uiDesigner.core.GridConstraints(2, 1, 1, 1,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.ANCHOR_SOUTH,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                     null, null, null, 0, false));
        disconnectButtonC = new JButton();
        disconnectButtonC.setText("Disconnect");
        blPanel.add(disconnectButtonC, new com.intellij.uiDesigner.core.GridConstraints(2, 2, 1, 1,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.ANCHOR_SOUTHEAST,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                        null, null, null, 0, false));
        brPanel = new JPanel();
        brPanel.setLayout(new com.intellij.uiDesigner.core.GridLayoutManager(3, 3, new Insets(0, 0, 0, 0), -1, -1));
        outside.add(brPanel, new com.intellij.uiDesigner.core.GridConstraints(4, 3, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_BOTH,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              null, null, null, 0, true));
        brPanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createLineBorder(new Color(-10066330)),
                                                           "Connection #4"));
        labNameD = new JLabel();
        labNameD.setText("NAME");
        brPanel.add(labNameD, new com.intellij.uiDesigner.core.GridConstraints(0, 0, 1, 3,
                                                                               com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                               com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                               com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                               com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                               null, null, null, 0, false));
        labCountD = new JLabel();
        labCountD.setText("COUNT / 100");
        brPanel.add(labCountD, new com.intellij.uiDesigner.core.GridConstraints(1, 0, 1, 3,
                                                                                com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                                com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                null, null, null, 0, false));
        detailsButtonD = new JButton();
        detailsButtonD.setText("Details");
        brPanel.add(detailsButtonD, new com.intellij.uiDesigner.core.GridConstraints(2, 0, 1, 1,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.ANCHOR_SOUTHWEST,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                     null, null, null, 0, false));
        optionsButtonD = new JButton();
        optionsButtonD.setText("Options");
        brPanel.add(optionsButtonD, new com.intellij.uiDesigner.core.GridConstraints(2, 1, 1, 1,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.ANCHOR_SOUTH,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                     com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                     null, null, null, 0, false));
        disconnectButtonD = new JButton();
        disconnectButtonD.setText("Disconnect");
        brPanel.add(disconnectButtonD, new com.intellij.uiDesigner.core.GridConstraints(2, 2, 1, 1,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.ANCHOR_SOUTHEAST,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.FILL_NONE,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                        com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                        null, null, null, 0, false));
        final com.intellij.uiDesigner.core.Spacer spacer9 = new com.intellij.uiDesigner.core.Spacer();
        outside.add(spacer9, new com.intellij.uiDesigner.core.GridConstraints(2, 2, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              1, null, null, null, 0, false));
    }

    /**
     * @noinspection ALL
     */
    public JComponent $$$getRootComponent$$$()
    {
        return outside;
    }
}
