package com.perisic.beds.Control;

import org.apache.xmlrpc.XmlRpcClient;

import java.io.IOException;
import java.net.MalformedURLException;
import java.util.Vector;

/**
 * This class handles the connection to a remote recycling machine.
 * @author AH, AM, SA
 */
public class MachineConnection
{
    public boolean empty = true;

    private String ip;
    private String cookie;
    private XmlRpcClient server;

    /**
     * @param ipNo The IP of the remote machine
     */
    public MachineConnection(String ipNo)
    {
        empty = false;

        ip = ipNo;
    }

    /**
     * Attempts to locate and login to a recycling machine at the previously given IP
     * @param password The password of the remote machine
     * @return A status int -4 and 1. 1=success, -1=Remote related exception or no IP, -2=bad password, -3=machine already logged into, -4=other failure
     */
    public int tryConnect(String password)
    {
        Vector<String> parameters = new Vector<String>();
        parameters.add(password);

        if (ip == null || ip.equals(""))
        {
            return -1;
        }
        try
        {
            server = new XmlRpcClient("http://" + ip);
            String result = server.execute("recycling.login", parameters).toString();
            System.out.println(result);
            if (result.equals("bad password"))
            {
                return -2;
            }
            else if (result.equals("already logged"))
            {
                return -3;
            }
            else
            {
                cookie = result;
                return 1;
            }
        } catch (MalformedURLException ex)
        {
            return -1;
        }
        catch (IOException ex)
        {
            return -1;
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
            return -4;
        }
    }

    /**
     * @return The item total of the remote machine
     */
    public int getTotal()
    {
        int result;
        Vector<String> parameters = new Vector<String>();
        parameters.add(cookie);
        try
        {
            result = Integer.parseInt(
                    server.execute("recycling.getItemCount", parameters).toString());
        }
        catch (Exception ex)
        {
            return -2;
        }
        return result;
    }

    /**
     * Logs out of the remote machine
     */
    public void disconnect()
    {
        Vector parameters = new Vector();
        try
        {
            server.execute("recycling.logout", parameters);
        }
        catch(Exception ex)
        {
            ex.printStackTrace();
        }
        finally
        {
            ip = null;
            server = null;
            cookie = null;
        }
    }

    /**
     * Empties the remote machine
     */
    public void emptyMachine()
    {
        Vector<String> parameters = new Vector<String>();
        parameters.add(cookie);

        try
        {
            server.execute("recycling.emptyMachine", parameters);
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
    }

    /**
     * Retrieves feedback from the remote machine
     * @return Feedback from the remote machine
     */
    public Vector<String> getFeedback()
    {
        Vector<String> result;
        Vector<String> parameters = new Vector<String>();
        parameters.add(cookie);

        try
        {
            result = (Vector<String>)server.execute("recycling.getFeedback", parameters);
        }
        catch (Exception ex)
        {
            result = new Vector<String>();
            result.add("Error encountered: " + ex.toString());
        }
        return result;
    }

    /**
     * Retries the detailed item total from the remote machine
     * @return A formatted string of the detailed item total from the remote machine
     */
    public String getDetails()
    {
        Vector<String> result;
        String[] resultS;

        Vector<String> parameters = new Vector<String>();
        parameters.add(cookie);

        try
        {
            result = (Vector<String>)server.execute("recycling.getDetailedTotal", parameters);
            resultS = result.toArray(new String[result.size()]);
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
            return "Error getting details";
        }

        if(resultS.length > 1)
        {
            String ret = "";
            ret += resultS[0] + " Cans\r\n";
            ret += resultS[1] + " Plastic Bottles\r\n";
            ret += resultS[2] + " Glass Bottles\r\n";
            ret += resultS[3] + " Bags\r\n";
            ret += resultS[4] + " Crates\r\n";
            return ret;
        }
        else
        {
            return "Error getting details";
        }
    }
}
