package com.perisic.beds.Machine;

import java.util.Random;

/**
 * This class sorts deposited items based on slot, and handles the Printerface and ReceiptBasis
 * @author AH
 */
public class DepositItemReceiver
{
    private int totalGBottleCount = 0;
    private int totalPBottleCount = 0;
    private int totalBagCount = 0;
    private int totalCanCount = 0;
    private int totalCrateCount = 0;

    private int gBottleCount = 0;
    private int pBottleCount = 0;
    private int bagCount = 0;
    private int canCount = 0;
    private int crateCount = 0;

    private int itemCount = 0;

    /**
     * @param printer The Printerface to be used for outputting receipts
     */
    public DepositItemReceiver(Printerface printer)
    {
        super();
        this.printer = printer;
    }
    ReceiptBasis theReceiptBasis = null;
    Printerface printer = null;
    /**
     * Instantiates a ReceiptBasis
     */
    public void createReceiptBasis()
    {
        theReceiptBasis = new ReceiptBasis();
    }
    /**
     * Sorts items based on slot that they entered
     * @param slot The slot that the can/bottle/crate entered
     * @throws MachineFullException Exception is thrown if the machine is full
     */
    public void classifyItem(int slot) throws MachineFullException
    {
        DepositItem item = null;
        switch(slot)
        {
            case 1:
                item = new Can();
                canCount++;
                totalCanCount++;
                break;
            case 2:
                /**
                 * The machine does not truly support weight, because the machine isn't real.
                 */
                Random r = new Random();
                int weight = r.nextInt(2);

                if(weight == 0)
                {
                    item = new GlassBottle();
                    gBottleCount++;
                    totalGBottleCount++;
                }
                else
                {
                    item = new PlasticBottle();
                    pBottleCount++;
                    totalPBottleCount++;
                }

                break;
            case 3:
                item = new Crate();
                crateCount++;
                totalCrateCount++;
                break;
            case 4:
                item = new Bag();
                bagCount++;
                totalBagCount++;
                break;
            default:
                break;
        }

        if( theReceiptBasis == null )
        {
            createReceiptBasis();
        }

        if(itemCount < 100)
        {
            theReceiptBasis.addItem(item);
            itemCount++;
        }
        else
        {
            throw new MachineFullException("This machine is currently full.\nWe apologise for any inconvenience.");
        }
    }

    /**
     * Resets the counters used as part of generating receipts.
     */
    private void resetCounters()
    {
        canCount = 0;
        pBottleCount = 0;
        gBottleCount = 0;
        bagCount = 0;
        crateCount = 0;
    }

    /**
     * @return The total item count in the machine
     */
    public int getTotal()
    {
        return itemCount;
    }

    /**
     * @return An int array of the totals of each type of item. 0=cans, 1=p.bottles, 2=g.bottles, 3=bags, 4=crates
     */
    public int[] getDetailedTotal()
    {
        int[] ret = new int[5];
        ret[0] = totalCanCount;
        ret[1] = totalPBottleCount;
        ret[2] = totalGBottleCount;
        ret[3] = totalBagCount;
        ret[4] = totalCrateCount;
        return ret;
    }

    /**
     * Resets the machine's total counters. Does not reset the active receipt.
     */
    public void emptyMachine()
    {
        itemCount = 0;
        totalCanCount = 0;
        totalPBottleCount = 0;
        totalGBottleCount = 0;
        totalBagCount = 0;
        totalCrateCount = 0;
    }

    /**
     * Uses a ReceiptBasis to compute the receipt's sum and then passes that string to the Printerface. Then the ReceiptBasis is reset.
     */
    public void printReceipt()
    {
        if(theReceiptBasis != null)
        {
            String str = theReceiptBasis.computeSum();
            //int[] items = {gBottleCount, pBottleCount, bagCount, canCount, crateCount};
            str = str + "\n\rGlass Bottles: " + gBottleCount + "\n\rPlastic Bottles: " + pBottleCount + "\n\rBags: " + bagCount + "\n\rCans: " + canCount + "\n\rCrates: " + crateCount;
            printer.print(str);
            theReceiptBasis = null;
            resetCounters();
        }
    }
}
