package com.perisic.beds.Machine;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.net.*;

import org.apache.xmlrpc.WebServer;

/**
 * Main GUI class
 * @author AH
 */
public class SlotsForm implements ActionListener
{
    private JButton button1;
    private JButton slot2Button;
    private JButton slot3Button;
    private JButton slot4Button;
    private JButton receiptButton;
    private JTextField returnTextField;
    private JPanel outside;
    private JTextArea receiptArea;
    private JButton feedbackBut;

    private CustomerPanel cp;

    private BoxReset br;

//    private boolean full = false;

    //    private ExitThread et;
    private String ip;


    /**
     * Constructor. Initialises a customer panel and adds actionListeners.
     */
    public SlotsForm()
    {
        cp = new CustomerPanel(new PrinterArea(receiptArea));

        button1.addActionListener(this);
        slot2Button.addActionListener(this);
        slot3Button.addActionListener(this);
        slot4Button.addActionListener(this);
        receiptButton.addActionListener(this);
        feedbackBut.addActionListener(this);

        receiptArea.setVisible(false);

        try
        {
            System.out.println("Starting server...");
            String ipNo = null;
            try
            {
                ipNo = InetAddress.getLocalHost().getHostAddress();
                System.out.println("IP: " + ipNo);
            } catch (UnknownHostException ex)
            {
                System.err.println("Unknown host: " + ex.toString());
            }

            WebServer server = new WebServer(80);
            server.addHandler("recycling", cp);
            server.start();
            HTTPHandler.getData(
                    "http://spacewalrus.net/cgi-bin/post-ip-compara.py",
                    "ip=" + ipNo + "&action=add");
//            Runtime.getRuntime().addShutdownHook(new ExitThread(ipNo));
//            et = new ExitThread(ipNo);
            ip = ipNo;
        } catch (Exception ex)
        {
            System.err.println("Control exception: " + ex.toString());
        }
    }


    /**
     * This method attempts to add an item to the machine. It will fail if the machine is full.
     *
     * @param slot The slot that the item has been desposited into.
     */
    private void tryAdd(int slot)
    {
        try
        {
            cp.itemReceived(slot);
            if (br != null)
            {
                br.interrupt();
            }

            br = new BoxReset(returnTextField);
            br.start();
        } catch (MachineFullException ex)
        {
            //JOptionPane.showMessageDialog(null, ex.getMessage());
            MessageThread mt = new MessageThread(ex.getMessage());
            mt.start();
//            full = true;
            if (br != null)
            {
                br.interrupt();
            }
            returnTextField.setText("This Machine is FULL.");
        }
    }


    /**
     * Handler for buttons.
     *
     * @param e Event from the button.
     */
    public void actionPerformed(ActionEvent e)
    {
        receiptArea.setVisible(false);

        String type = e.getActionCommand();

//        if (full == false)
//        {
        if (type.equals("Slot 1"))
        {
            //Can
            returnTextField.setText("Can Deposited...");
            tryAdd(1);
        }
        else if (type.equals("Slot 2"))
        {
            //Bottle
            returnTextField.setText("Bottle Deposited...");
            tryAdd(2);
        }
        else if (type.equals("Slot 3"))
        {
            //Crate
            returnTextField.setText("Crate Deposited...");
            tryAdd(3);
        }
        else if (type.equals("Slot 4"))
        {
            //Bag
            returnTextField.setText("Bag Deposited...");
            tryAdd(4);
        }
        else if (type.equals("Print receipt"))
        {
            returnTextField.setText("Printing receipt...");
            cp.printReceipt();
            receiptArea.setVisible(true);

            if (br != null)
            {
                br.interrupt();
            }

            br = new BoxReset(returnTextField);
            br.start();
        }
//        }
        else if (type.equals("Leave Feedback"))
        {
            FeedbackThread fbt = new FeedbackThread(cp);
            fbt.start();
        }

    }

    /**
     * Main method that starts the recycling machine, sets the GUI size and properties.
     *
     * @param args Standard main args
     */
    public static void main(String[] args)
    {
        SlotsForm sf = new SlotsForm();
        JFrame frame = new JFrame("Recycling Machine");
        frame.setContentPane(sf.outside);
        frame.addWindowListener(new WindowAdapter()
        {
            @Override
            public void windowClosing(WindowEvent windowEvent)
            {
                try
                {
                    HTTPHandler.getData(
                            "http://spacewalrus.net/cgi-bin/post-ip-compara.py",
                            "ip=" + InetAddress.getLocalHost().getHostAddress() + "&action=remove");
                } catch (Exception ex)
                {
                    ex.printStackTrace();
                } finally
                {
                    System.exit(0);
                }
            }
        });
        frame.pack();
        frame.setSize(650, 450);
        frame.setVisible(true);
    }

    {
// GUI initializer generated by IntelliJ IDEA GUI Designer
// >>> IMPORTANT!! <<<
// DO NOT EDIT OR ADD ANY CODE HERE!
        $$$setupUI$$$();
    }

    /**
     * Method generated by IntelliJ IDEA GUI Designer
     * >>> IMPORTANT!! <<<
     * DO NOT edit this method OR call it in your code!
     *
     * @noinspection ALL
     */
    private void $$$setupUI$$$()
    {
        outside = new JPanel();
        outside.setLayout(new com.intellij.uiDesigner.core.GridLayoutManager(8, 7, new Insets(0, 0, 0, 0), -1, -1));
        outside.setEnabled(false);
        final com.intellij.uiDesigner.core.Spacer spacer1 = new com.intellij.uiDesigner.core.Spacer();
        outside.add(spacer1, new com.intellij.uiDesigner.core.GridConstraints(3, 0, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              1, null, null, null, 0, false));
        slot3Button = new JButton();
        slot3Button.setIcon(new ImageIcon(getClass().getResource("/com/perisic/beds/Machine/images/crate.PNG")));
        slot3Button.setText("Slot 3");
        outside.add(slot3Button, new com.intellij.uiDesigner.core.GridConstraints(3, 4, 1, 1,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                  null, new Dimension(124, 90), null, 0,
                                                                                  false));
        slot4Button = new JButton();
        slot4Button.setIcon(new ImageIcon(getClass().getResource("/com/perisic/beds/Machine/images/bag.PNG")));
        slot4Button.setText("Slot 4");
        outside.add(slot4Button, new com.intellij.uiDesigner.core.GridConstraints(3, 5, 1, 1,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                  null, null, null, 0, false));
        final com.intellij.uiDesigner.core.Spacer spacer2 = new com.intellij.uiDesigner.core.Spacer();
        outside.add(spacer2, new com.intellij.uiDesigner.core.GridConstraints(3, 6, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                              1, null, null, null, 0, false));
        receiptButton = new JButton();
        receiptButton.setText("Print receipt");
        outside.add(receiptButton, new com.intellij.uiDesigner.core.GridConstraints(5, 2, 1, 3,
                                                                                    com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                                    com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                                    com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                    com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                    null, null, null, 0, false));
        slot2Button = new JButton();
        slot2Button.setIcon(new ImageIcon(getClass().getResource("/com/perisic/beds/Machine/images/bottle.png")));
        slot2Button.setText("Slot 2");
        outside.add(slot2Button, new com.intellij.uiDesigner.core.GridConstraints(3, 2, 1, 1,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                  null, null, null, 0, false));
        returnTextField = new JTextField();
        returnTextField.setText("Please deposit items...");
        outside.add(returnTextField, new com.intellij.uiDesigner.core.GridConstraints(1, 2, 1, 3,
                                                                                      com.intellij.uiDesigner.core.GridConstraints.ANCHOR_WEST,
                                                                                      com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                                      com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                                      com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                      null, new Dimension(150, -1),
                                                                                      null, 0, false));
        button1 = new JButton();
        button1.setIcon(new ImageIcon(getClass().getResource("/com/perisic/beds/Machine/images/can.PNG")));
        button1.setText("Slot 1");
        outside.add(button1, new com.intellij.uiDesigner.core.GridConstraints(3, 1, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                              null, null, null, 0, false));
        final com.intellij.uiDesigner.core.Spacer spacer3 = new com.intellij.uiDesigner.core.Spacer();
        outside.add(spacer3, new com.intellij.uiDesigner.core.GridConstraints(4, 3, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_VERTICAL,
                                                                              1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                              null, null, null, 0, false));
        final com.intellij.uiDesigner.core.Spacer spacer4 = new com.intellij.uiDesigner.core.Spacer();
        outside.add(spacer4, new com.intellij.uiDesigner.core.GridConstraints(2, 3, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_VERTICAL,
                                                                              1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                              null, null, null, 0, false));
        final JScrollPane scrollPane1 = new JScrollPane();
        outside.add(scrollPane1, new com.intellij.uiDesigner.core.GridConstraints(6, 2, 1, 3,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.FILL_BOTH,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_WANT_GROW,
                                                                                  null, null, null, 0, false));
        scrollPane1.setBorder(BorderFactory.createTitledBorder("Receipt"));
        receiptArea = new JTextArea();
        receiptArea.setEditable(false);
        scrollPane1.setViewportView(receiptArea);
        final com.intellij.uiDesigner.core.Spacer spacer5 = new com.intellij.uiDesigner.core.Spacer();
        outside.add(spacer5, new com.intellij.uiDesigner.core.GridConstraints(0, 3, 1, 1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                              com.intellij.uiDesigner.core.GridConstraints.FILL_VERTICAL,
                                                                              1,
                                                                              com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                              null, null, null, 0, false));
        feedbackBut = new JButton();
        feedbackBut.setText("Leave Feedback");
        outside.add(feedbackBut, new com.intellij.uiDesigner.core.GridConstraints(7, 4, 1, 1,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.ANCHOR_CENTER,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.FILL_HORIZONTAL,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_SHRINK | com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_CAN_GROW,
                                                                                  com.intellij.uiDesigner.core.GridConstraints.SIZEPOLICY_FIXED,
                                                                                  null, null, null, 0, false));
    }

    /**
     * @noinspection ALL
     */
    public JComponent $$$getRootComponent$$$()
    {
        return outside;
    }
}
